@@ -4,8 +4,6 @@ from eepackages import utils
 
 # migrated from JavaScript users/gena/packages/assets.js
 
-# TODO: currently is's hacked together, ugly-ugly :( - refactor, re-use code developed for reservoir water detection 
-
 def cloudMaskAlgorithms_L8(image):
     qa = image.select('BQA')
     # /// Check that the cloud bit is off.
@@ -291,13 +289,13 @@ def getImages(g, options):
             area = g.area(scale)
 
             def f(i):
-                maskedArea = ee.Image.pixelArea().updateMask(i.select(0).mask()).reduceRegion(ee.Reducer.sum(), g, scale * 10).values().get(0)
+                maskedArea = ee.Image.pixelArea().updateMask(i.select(0).mask()).reduceRegion(ee.Reducer.sum(), g, ee.Number(scale).multiply(10)).values().get(0)
                 return i.set({'maskedFraction': ee.Number(maskedArea).divide(area)}) 
 
             images = images.map(f).filter(ee.Filter.gt('maskedFraction', options['filterMaskedFraction']))
         else:
             #    get images covering bounds 100% 
-            images = images.map(lambda i: i.set({'complete': i.select(0).mask().reduceRegion(ee.Reducer.allNonZero(), g, scale * 10).values().get(0)})).filter(ee.Filter.eq('complete', 1))
+            images = images.map(lambda i: i.set({'complete': i.select(0).mask().reduceRegion(ee.Reducer.allNonZero(), g, ee.Number(scale).multiply(10)).values().get(0)})).filter(ee.Filter.eq('complete', 1))
 
     # exclude night images
     images = images.filter(ee.Filter.gt('SUN_ELEVATION', 0))
@@ -312,12 +310,6 @@ def getImages(g, options):
 #  * This function mosaics images by time.
 #  */
 def mosaicByTime(images):
-    """
-    Sentinel-2 produces multiple images, resultsing sometimes 4x more images than the actual size. 
-    This is bad for any statistical analysis.
-
-    This function mosaics images by time.
-    """
     TIME_FIELD = 'system:time_start'
 
     distinct = images.distinct([TIME_FIELD])
@@ -390,7 +382,7 @@ def getMostlyCleanImages(images, g, options):
     
     cloudFrequency = (modisClouds.divide(10000).reduceRegion(
         ee.Reducer.percentile([p]), 
-        g.buffer(10000, scale*10), scale*10).values().get(0))
+        g.buffer(10000, ee.Number(scale).multiply(10)), ee.Number(scale).multiply(10)).values().get(0))
         
     # print('Cloud frequency (over AOI):', cloudFrequency)
     
